import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { WorkMailServiceException as __BaseException } from "./WorkMailServiceException";
export declare const AccessControlRuleEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type AccessControlRuleEffect =
  (typeof AccessControlRuleEffect)[keyof typeof AccessControlRuleEffect];
export interface AccessControlRule {
  Name?: string | undefined;
  Effect?: AccessControlRuleEffect | undefined;
  Description?: string | undefined;
  IpRanges?: string[] | undefined;
  NotIpRanges?: string[] | undefined;
  Actions?: string[] | undefined;
  NotActions?: string[] | undefined;
  UserIds?: string[] | undefined;
  NotUserIds?: string[] | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
  ImpersonationRoleIds?: string[] | undefined;
  NotImpersonationRoleIds?: string[] | undefined;
}
export declare const AccessEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type AccessEffect = (typeof AccessEffect)[keyof typeof AccessEffect];
export interface AssociateDelegateToResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  EntityId: string | undefined;
}
export interface AssociateDelegateToResourceResponse {}
export declare class EntityNotFoundException extends __BaseException {
  readonly name: "EntityNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EntityNotFoundException, __BaseException>
  );
}
export declare class EntityStateException extends __BaseException {
  readonly name: "EntityStateException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EntityStateException, __BaseException>
  );
}
export declare class InvalidParameterException extends __BaseException {
  readonly name: "InvalidParameterException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidParameterException, __BaseException>
  );
}
export declare class OrganizationNotFoundException extends __BaseException {
  readonly name: "OrganizationNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<OrganizationNotFoundException, __BaseException>
  );
}
export declare class OrganizationStateException extends __BaseException {
  readonly name: "OrganizationStateException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<OrganizationStateException, __BaseException>
  );
}
export declare class UnsupportedOperationException extends __BaseException {
  readonly name: "UnsupportedOperationException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<UnsupportedOperationException, __BaseException>
  );
}
export interface AssociateMemberToGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  MemberId: string | undefined;
}
export interface AssociateMemberToGroupResponse {}
export declare class DirectoryServiceAuthenticationFailedException extends __BaseException {
  readonly name: "DirectoryServiceAuthenticationFailedException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      DirectoryServiceAuthenticationFailedException,
      __BaseException
    >
  );
}
export declare class DirectoryUnavailableException extends __BaseException {
  readonly name: "DirectoryUnavailableException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DirectoryUnavailableException, __BaseException>
  );
}
export interface AssumeImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface AssumeImpersonationRoleResponse {
  Token?: string | undefined;
  ExpiresIn?: number | undefined;
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface RedactedEwsAvailabilityProvider {
  EwsEndpoint?: string | undefined;
  EwsUsername?: string | undefined;
}
export interface LambdaAvailabilityProvider {
  LambdaArn: string | undefined;
}
export declare const AvailabilityProviderType: {
  readonly EWS: "EWS";
  readonly LAMBDA: "LAMBDA";
};
export type AvailabilityProviderType =
  (typeof AvailabilityProviderType)[keyof typeof AvailabilityProviderType];
export interface AvailabilityConfiguration {
  DomainName?: string | undefined;
  ProviderType?: AvailabilityProviderType | undefined;
  EwsProvider?: RedactedEwsAvailabilityProvider | undefined;
  LambdaProvider?: LambdaAvailabilityProvider | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export interface BookingOptions {
  AutoAcceptRequests?: boolean | undefined;
  AutoDeclineRecurringRequests?: boolean | undefined;
  AutoDeclineConflictingRequests?: boolean | undefined;
}
export interface CancelMailboxExportJobRequest {
  ClientToken?: string | undefined;
  JobId: string | undefined;
  OrganizationId: string | undefined;
}
export interface CancelMailboxExportJobResponse {}
export interface CreateAliasRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Alias: string | undefined;
}
export interface CreateAliasResponse {}
export declare class EmailAddressInUseException extends __BaseException {
  readonly name: "EmailAddressInUseException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EmailAddressInUseException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class MailDomainNotFoundException extends __BaseException {
  readonly name: "MailDomainNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<MailDomainNotFoundException, __BaseException>
  );
}
export declare class MailDomainStateException extends __BaseException {
  readonly name: "MailDomainStateException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<MailDomainStateException, __BaseException>
  );
}
export interface EwsAvailabilityProvider {
  EwsEndpoint: string | undefined;
  EwsUsername: string | undefined;
  EwsPassword: string | undefined;
}
export interface CreateAvailabilityConfigurationRequest {
  ClientToken?: string | undefined;
  OrganizationId: string | undefined;
  DomainName: string | undefined;
  EwsProvider?: EwsAvailabilityProvider | undefined;
  LambdaProvider?: LambdaAvailabilityProvider | undefined;
}
export interface CreateAvailabilityConfigurationResponse {}
export declare class NameAvailabilityException extends __BaseException {
  readonly name: "NameAvailabilityException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NameAvailabilityException, __BaseException>
  );
}
export interface CreateGroupRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface CreateGroupResponse {
  GroupId?: string | undefined;
}
export declare class ReservedNameException extends __BaseException {
  readonly name: "ReservedNameException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ReservedNameException, __BaseException>
  );
}
export interface CreateIdentityCenterApplicationRequest {
  Name: string | undefined;
  InstanceArn: string | undefined;
  ClientToken?: string | undefined;
}
export interface CreateIdentityCenterApplicationResponse {
  ApplicationArn?: string | undefined;
}
export interface ImpersonationRule {
  ImpersonationRuleId: string | undefined;
  Name?: string | undefined;
  Description?: string | undefined;
  Effect: AccessEffect | undefined;
  TargetUsers?: string[] | undefined;
  NotTargetUsers?: string[] | undefined;
}
export declare const ImpersonationRoleType: {
  readonly FULL_ACCESS: "FULL_ACCESS";
  readonly READ_ONLY: "READ_ONLY";
};
export type ImpersonationRoleType =
  (typeof ImpersonationRoleType)[keyof typeof ImpersonationRoleType];
export interface CreateImpersonationRoleRequest {
  ClientToken?: string | undefined;
  OrganizationId: string | undefined;
  Name: string | undefined;
  Type: ImpersonationRoleType | undefined;
  Description?: string | undefined;
  Rules: ImpersonationRule[] | undefined;
}
export interface CreateImpersonationRoleResponse {
  ImpersonationRoleId?: string | undefined;
}
export declare const MobileDeviceAccessRuleEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type MobileDeviceAccessRuleEffect =
  (typeof MobileDeviceAccessRuleEffect)[keyof typeof MobileDeviceAccessRuleEffect];
export interface CreateMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  ClientToken?: string | undefined;
  Name: string | undefined;
  Description?: string | undefined;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  DeviceTypes?: string[] | undefined;
  NotDeviceTypes?: string[] | undefined;
  DeviceModels?: string[] | undefined;
  NotDeviceModels?: string[] | undefined;
  DeviceOperatingSystems?: string[] | undefined;
  NotDeviceOperatingSystems?: string[] | undefined;
  DeviceUserAgents?: string[] | undefined;
  NotDeviceUserAgents?: string[] | undefined;
}
export interface CreateMobileDeviceAccessRuleResponse {
  MobileDeviceAccessRuleId?: string | undefined;
}
export interface Domain {
  DomainName: string | undefined;
  HostedZoneId?: string | undefined;
}
export interface CreateOrganizationRequest {
  DirectoryId?: string | undefined;
  Alias: string | undefined;
  ClientToken?: string | undefined;
  Domains?: Domain[] | undefined;
  KmsKeyArn?: string | undefined;
  EnableInteroperability?: boolean | undefined;
}
export interface CreateOrganizationResponse {
  OrganizationId?: string | undefined;
}
export declare class DirectoryInUseException extends __BaseException {
  readonly name: "DirectoryInUseException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DirectoryInUseException, __BaseException>
  );
}
export declare const ResourceType: {
  readonly EQUIPMENT: "EQUIPMENT";
  readonly ROOM: "ROOM";
};
export type ResourceType = (typeof ResourceType)[keyof typeof ResourceType];
export interface CreateResourceRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  Type: ResourceType | undefined;
  Description?: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface CreateResourceResponse {
  ResourceId?: string | undefined;
}
export declare const UserRole: {
  readonly REMOTE_USER: "REMOTE_USER";
  readonly RESOURCE: "RESOURCE";
  readonly SYSTEM_USER: "SYSTEM_USER";
  readonly USER: "USER";
};
export type UserRole = (typeof UserRole)[keyof typeof UserRole];
export interface CreateUserRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  DisplayName: string | undefined;
  Password?: string | undefined;
  Role?: UserRole | undefined;
  FirstName?: string | undefined;
  LastName?: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
  IdentityProviderUserId?: string | undefined;
}
export interface CreateUserResponse {
  UserId?: string | undefined;
}
export declare class InvalidPasswordException extends __BaseException {
  readonly name: "InvalidPasswordException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidPasswordException, __BaseException>
  );
}
export declare const MemberType: {
  readonly GROUP: "GROUP";
  readonly USER: "USER";
};
export type MemberType = (typeof MemberType)[keyof typeof MemberType];
export interface Delegate {
  Id: string | undefined;
  Type: MemberType | undefined;
}
export interface DeleteAccessControlRuleRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
}
export interface DeleteAccessControlRuleResponse {}
export interface DeleteAliasRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Alias: string | undefined;
}
export interface DeleteAliasResponse {}
export interface DeleteAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface DeleteAvailabilityConfigurationResponse {}
export interface DeleteEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
}
export interface DeleteEmailMonitoringConfigurationResponse {}
export interface DeleteGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
}
export interface DeleteGroupResponse {}
export interface DeleteIdentityCenterApplicationRequest {
  ApplicationArn: string | undefined;
}
export interface DeleteIdentityCenterApplicationResponse {}
export interface DeleteIdentityProviderConfigurationRequest {
  OrganizationId: string | undefined;
}
export interface DeleteIdentityProviderConfigurationResponse {}
export interface DeleteImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface DeleteImpersonationRoleResponse {}
export interface DeleteMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  GranteeId: string | undefined;
}
export interface DeleteMailboxPermissionsResponse {}
export interface DeleteMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
}
export interface DeleteMobileDeviceAccessOverrideResponse {}
export interface DeleteMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  MobileDeviceAccessRuleId: string | undefined;
}
export interface DeleteMobileDeviceAccessRuleResponse {}
export interface DeleteOrganizationRequest {
  ClientToken?: string | undefined;
  OrganizationId: string | undefined;
  DeleteDirectory: boolean | undefined;
  ForceDelete?: boolean | undefined;
  DeleteIdentityCenterApplication?: boolean | undefined;
}
export interface DeleteOrganizationResponse {
  OrganizationId?: string | undefined;
  State?: string | undefined;
}
export interface DeletePersonalAccessTokenRequest {
  OrganizationId: string | undefined;
  PersonalAccessTokenId: string | undefined;
}
export interface DeletePersonalAccessTokenResponse {}
export interface DeleteResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
}
export interface DeleteResourceResponse {}
export interface DeleteRetentionPolicyRequest {
  OrganizationId: string | undefined;
  Id: string | undefined;
}
export interface DeleteRetentionPolicyResponse {}
export interface DeleteUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface DeleteUserResponse {}
export interface DeregisterFromWorkMailRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
}
export interface DeregisterFromWorkMailResponse {}
export interface DeregisterMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface DeregisterMailDomainResponse {}
export declare class InvalidCustomSesConfigurationException extends __BaseException {
  readonly name: "InvalidCustomSesConfigurationException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      InvalidCustomSesConfigurationException,
      __BaseException
    >
  );
}
export declare class MailDomainInUseException extends __BaseException {
  readonly name: "MailDomainInUseException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<MailDomainInUseException, __BaseException>
  );
}
export interface DescribeEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
}
export interface DescribeEmailMonitoringConfigurationResponse {
  RoleArn?: string | undefined;
  LogGroupArn?: string | undefined;
}
export interface DescribeEntityRequest {
  OrganizationId: string | undefined;
  Email: string | undefined;
}
export declare const EntityType: {
  readonly GROUP: "GROUP";
  readonly RESOURCE: "RESOURCE";
  readonly USER: "USER";
};
export type EntityType = (typeof EntityType)[keyof typeof EntityType];
export interface DescribeEntityResponse {
  EntityId?: string | undefined;
  Name?: string | undefined;
  Type?: EntityType | undefined;
}
export interface DescribeGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
}
export declare const EntityState: {
  readonly DELETED: "DELETED";
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type EntityState = (typeof EntityState)[keyof typeof EntityState];
export interface DescribeGroupResponse {
  GroupId?: string | undefined;
  Name?: string | undefined;
  Email?: string | undefined;
  State?: EntityState | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface DescribeIdentityProviderConfigurationRequest {
  OrganizationId: string | undefined;
}
export declare const IdentityProviderAuthenticationMode: {
  readonly IDENTITY_PROVIDER_AND_DIRECTORY: "IDENTITY_PROVIDER_AND_DIRECTORY";
  readonly IDENTITY_PROVIDER_ONLY: "IDENTITY_PROVIDER_ONLY";
};
export type IdentityProviderAuthenticationMode =
  (typeof IdentityProviderAuthenticationMode)[keyof typeof IdentityProviderAuthenticationMode];
export interface IdentityCenterConfiguration {
  InstanceArn: string | undefined;
  ApplicationArn: string | undefined;
}
export declare const PersonalAccessTokenConfigurationStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly INACTIVE: "INACTIVE";
};
export type PersonalAccessTokenConfigurationStatus =
  (typeof PersonalAccessTokenConfigurationStatus)[keyof typeof PersonalAccessTokenConfigurationStatus];
export interface PersonalAccessTokenConfiguration {
  Status: PersonalAccessTokenConfigurationStatus | undefined;
  LifetimeInDays?: number | undefined;
}
export interface DescribeIdentityProviderConfigurationResponse {
  AuthenticationMode?: IdentityProviderAuthenticationMode | undefined;
  IdentityCenterConfiguration?: IdentityCenterConfiguration | undefined;
  PersonalAccessTokenConfiguration?:
    | PersonalAccessTokenConfiguration
    | undefined;
}
export interface DescribeInboundDmarcSettingsRequest {
  OrganizationId: string | undefined;
}
export interface DescribeInboundDmarcSettingsResponse {
  Enforced?: boolean | undefined;
}
export interface DescribeMailboxExportJobRequest {
  JobId: string | undefined;
  OrganizationId: string | undefined;
}
export declare const MailboxExportJobState: {
  readonly CANCELLED: "CANCELLED";
  readonly COMPLETED: "COMPLETED";
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
};
export type MailboxExportJobState =
  (typeof MailboxExportJobState)[keyof typeof MailboxExportJobState];
export interface DescribeMailboxExportJobResponse {
  EntityId?: string | undefined;
  Description?: string | undefined;
  RoleArn?: string | undefined;
  KmsKeyArn?: string | undefined;
  S3BucketName?: string | undefined;
  S3Prefix?: string | undefined;
  S3Path?: string | undefined;
  EstimatedProgress?: number | undefined;
  State?: MailboxExportJobState | undefined;
  ErrorInfo?: string | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
}
export interface DescribeOrganizationRequest {
  OrganizationId: string | undefined;
}
export interface DescribeOrganizationResponse {
  OrganizationId?: string | undefined;
  Alias?: string | undefined;
  State?: string | undefined;
  DirectoryId?: string | undefined;
  DirectoryType?: string | undefined;
  DefaultMailDomain?: string | undefined;
  CompletedDate?: Date | undefined;
  ErrorMessage?: string | undefined;
  ARN?: string | undefined;
  MigrationAdmin?: string | undefined;
  InteroperabilityEnabled?: boolean | undefined;
}
export interface DescribeResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
}
export interface DescribeResourceResponse {
  ResourceId?: string | undefined;
  Email?: string | undefined;
  Name?: string | undefined;
  Type?: ResourceType | undefined;
  BookingOptions?: BookingOptions | undefined;
  State?: EntityState | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
  Description?: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface DescribeUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface DescribeUserResponse {
  UserId?: string | undefined;
  Name?: string | undefined;
  Email?: string | undefined;
  DisplayName?: string | undefined;
  State?: EntityState | undefined;
  UserRole?: UserRole | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
  MailboxProvisionedDate?: Date | undefined;
  MailboxDeprovisionedDate?: Date | undefined;
  FirstName?: string | undefined;
  LastName?: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
  Initials?: string | undefined;
  Telephone?: string | undefined;
  Street?: string | undefined;
  JobTitle?: string | undefined;
  City?: string | undefined;
  Company?: string | undefined;
  ZipCode?: string | undefined;
  Department?: string | undefined;
  Country?: string | undefined;
  Office?: string | undefined;
  IdentityProviderUserId?: string | undefined;
  IdentityProviderIdentityStoreId?: string | undefined;
}
export interface DisassociateDelegateFromResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  EntityId: string | undefined;
}
export interface DisassociateDelegateFromResourceResponse {}
export interface DisassociateMemberFromGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  MemberId: string | undefined;
}
export interface DisassociateMemberFromGroupResponse {}
export interface DnsRecord {
  Type?: string | undefined;
  Hostname?: string | undefined;
  Value?: string | undefined;
}
export declare const DnsRecordVerificationStatus: {
  readonly FAILED: "FAILED";
  readonly PENDING: "PENDING";
  readonly VERIFIED: "VERIFIED";
};
export type DnsRecordVerificationStatus =
  (typeof DnsRecordVerificationStatus)[keyof typeof DnsRecordVerificationStatus];
export declare class EntityAlreadyRegisteredException extends __BaseException {
  readonly name: "EntityAlreadyRegisteredException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      EntityAlreadyRegisteredException,
      __BaseException
    >
  );
}
export declare const RetentionAction: {
  readonly DELETE: "DELETE";
  readonly NONE: "NONE";
  readonly PERMANENTLY_DELETE: "PERMANENTLY_DELETE";
};
export type RetentionAction =
  (typeof RetentionAction)[keyof typeof RetentionAction];
export declare const FolderName: {
  readonly DELETED_ITEMS: "DELETED_ITEMS";
  readonly DRAFTS: "DRAFTS";
  readonly INBOX: "INBOX";
  readonly JUNK_EMAIL: "JUNK_EMAIL";
  readonly SENT_ITEMS: "SENT_ITEMS";
};
export type FolderName = (typeof FolderName)[keyof typeof FolderName];
export interface FolderConfiguration {
  Name: FolderName | undefined;
  Action: RetentionAction | undefined;
  Period?: number | undefined;
}
export interface GetAccessControlEffectRequest {
  OrganizationId: string | undefined;
  IpAddress: string | undefined;
  Action: string | undefined;
  UserId?: string | undefined;
  ImpersonationRoleId?: string | undefined;
}
export interface GetAccessControlEffectResponse {
  Effect?: AccessControlRuleEffect | undefined;
  MatchedRules?: string[] | undefined;
}
export interface GetDefaultRetentionPolicyRequest {
  OrganizationId: string | undefined;
}
export interface GetDefaultRetentionPolicyResponse {
  Id?: string | undefined;
  Name?: string | undefined;
  Description?: string | undefined;
  FolderConfigurations?: FolderConfiguration[] | undefined;
}
export interface GetImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface GetImpersonationRoleResponse {
  ImpersonationRoleId?: string | undefined;
  Name?: string | undefined;
  Type?: ImpersonationRoleType | undefined;
  Description?: string | undefined;
  Rules?: ImpersonationRule[] | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export interface GetImpersonationRoleEffectRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
  TargetUser: string | undefined;
}
export interface ImpersonationMatchedRule {
  ImpersonationRuleId?: string | undefined;
  Name?: string | undefined;
}
export interface GetImpersonationRoleEffectResponse {
  Type?: ImpersonationRoleType | undefined;
  Effect?: AccessEffect | undefined;
  MatchedRules?: ImpersonationMatchedRule[] | undefined;
}
export interface GetMailboxDetailsRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface GetMailboxDetailsResponse {
  MailboxQuota?: number | undefined;
  MailboxSize?: number | undefined;
}
export interface GetMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface GetMailDomainResponse {
  Records?: DnsRecord[] | undefined;
  IsTestDomain?: boolean | undefined;
  IsDefault?: boolean | undefined;
  OwnershipVerificationStatus?: DnsRecordVerificationStatus | undefined;
  DkimVerificationStatus?: DnsRecordVerificationStatus | undefined;
}
export interface GetMobileDeviceAccessEffectRequest {
  OrganizationId: string | undefined;
  DeviceType?: string | undefined;
  DeviceModel?: string | undefined;
  DeviceOperatingSystem?: string | undefined;
  DeviceUserAgent?: string | undefined;
}
export interface MobileDeviceAccessMatchedRule {
  MobileDeviceAccessRuleId?: string | undefined;
  Name?: string | undefined;
}
export interface GetMobileDeviceAccessEffectResponse {
  Effect?: MobileDeviceAccessRuleEffect | undefined;
  MatchedRules?: MobileDeviceAccessMatchedRule[] | undefined;
}
export interface GetMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
}
export interface GetMobileDeviceAccessOverrideResponse {
  UserId?: string | undefined;
  DeviceId?: string | undefined;
  Effect?: MobileDeviceAccessRuleEffect | undefined;
  Description?: string | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export interface GetPersonalAccessTokenMetadataRequest {
  OrganizationId: string | undefined;
  PersonalAccessTokenId: string | undefined;
}
export interface GetPersonalAccessTokenMetadataResponse {
  PersonalAccessTokenId?: string | undefined;
  UserId?: string | undefined;
  Name?: string | undefined;
  DateCreated?: Date | undefined;
  DateLastUsed?: Date | undefined;
  ExpiresTime?: Date | undefined;
  Scopes?: string[] | undefined;
}
export interface Group {
  Id?: string | undefined;
  Email?: string | undefined;
  Name?: string | undefined;
  State?: EntityState | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
}
export interface GroupIdentifier {
  GroupId?: string | undefined;
  GroupName?: string | undefined;
}
export interface ImpersonationRole {
  ImpersonationRoleId?: string | undefined;
  Name?: string | undefined;
  Type?: ImpersonationRoleType | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export declare class InvalidConfigurationException extends __BaseException {
  readonly name: "InvalidConfigurationException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidConfigurationException, __BaseException>
  );
}
export interface MailboxExportJob {
  JobId?: string | undefined;
  EntityId?: string | undefined;
  Description?: string | undefined;
  S3BucketName?: string | undefined;
  S3Path?: string | undefined;
  EstimatedProgress?: number | undefined;
  State?: MailboxExportJobState | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
}
export interface ListAccessControlRulesRequest {
  OrganizationId: string | undefined;
}
export interface ListAccessControlRulesResponse {
  Rules?: AccessControlRule[] | undefined;
}
export interface ListAliasesRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListAliasesResponse {
  Aliases?: string[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAvailabilityConfigurationsRequest {
  OrganizationId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAvailabilityConfigurationsResponse {
  AvailabilityConfigurations?: AvailabilityConfiguration[] | undefined;
  NextToken?: string | undefined;
}
export interface ListGroupMembersRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface Member {
  Id?: string | undefined;
  Name?: string | undefined;
  Type?: MemberType | undefined;
  State?: EntityState | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
}
export interface ListGroupMembersResponse {
  Members?: Member[] | undefined;
  NextToken?: string | undefined;
}
export interface ListGroupsFilters {
  NamePrefix?: string | undefined;
  PrimaryEmailPrefix?: string | undefined;
  State?: EntityState | undefined;
}
export interface ListGroupsRequest {
  OrganizationId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  Filters?: ListGroupsFilters | undefined;
}
export interface ListGroupsResponse {
  Groups?: Group[] | undefined;
  NextToken?: string | undefined;
}
export interface ListGroupsForEntityFilters {
  GroupNamePrefix?: string | undefined;
}
export interface ListGroupsForEntityRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Filters?: ListGroupsForEntityFilters | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListGroupsForEntityResponse {
  Groups?: GroupIdentifier[] | undefined;
  NextToken?: string | undefined;
}
export interface ListImpersonationRolesRequest {
  OrganizationId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListImpersonationRolesResponse {
  Roles?: ImpersonationRole[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMailboxExportJobsRequest {
  OrganizationId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListMailboxExportJobsResponse {
  Jobs?: MailboxExportJob[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export declare const PermissionType: {
  readonly FULL_ACCESS: "FULL_ACCESS";
  readonly SEND_AS: "SEND_AS";
  readonly SEND_ON_BEHALF: "SEND_ON_BEHALF";
};
export type PermissionType =
  (typeof PermissionType)[keyof typeof PermissionType];
export interface Permission {
  GranteeId: string | undefined;
  GranteeType: MemberType | undefined;
  PermissionValues: PermissionType[] | undefined;
}
export interface ListMailboxPermissionsResponse {
  Permissions?: Permission[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMailDomainsRequest {
  OrganizationId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface MailDomainSummary {
  DomainName?: string | undefined;
  DefaultDomain?: boolean | undefined;
}
export interface ListMailDomainsResponse {
  MailDomains?: MailDomainSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMobileDeviceAccessOverridesRequest {
  OrganizationId: string | undefined;
  UserId?: string | undefined;
  DeviceId?: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface MobileDeviceAccessOverride {
  UserId?: string | undefined;
  DeviceId?: string | undefined;
  Effect?: MobileDeviceAccessRuleEffect | undefined;
  Description?: string | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export interface ListMobileDeviceAccessOverridesResponse {
  Overrides?: MobileDeviceAccessOverride[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMobileDeviceAccessRulesRequest {
  OrganizationId: string | undefined;
}
export interface MobileDeviceAccessRule {
  MobileDeviceAccessRuleId?: string | undefined;
  Name?: string | undefined;
  Description?: string | undefined;
  Effect?: MobileDeviceAccessRuleEffect | undefined;
  DeviceTypes?: string[] | undefined;
  NotDeviceTypes?: string[] | undefined;
  DeviceModels?: string[] | undefined;
  NotDeviceModels?: string[] | undefined;
  DeviceOperatingSystems?: string[] | undefined;
  NotDeviceOperatingSystems?: string[] | undefined;
  DeviceUserAgents?: string[] | undefined;
  NotDeviceUserAgents?: string[] | undefined;
  DateCreated?: Date | undefined;
  DateModified?: Date | undefined;
}
export interface ListMobileDeviceAccessRulesResponse {
  Rules?: MobileDeviceAccessRule[] | undefined;
}
export interface ListOrganizationsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface OrganizationSummary {
  OrganizationId?: string | undefined;
  Alias?: string | undefined;
  DefaultMailDomain?: string | undefined;
  ErrorMessage?: string | undefined;
  State?: string | undefined;
}
export interface ListOrganizationsResponse {
  OrganizationSummaries?: OrganizationSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPersonalAccessTokensRequest {
  OrganizationId: string | undefined;
  UserId?: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface PersonalAccessTokenSummary {
  PersonalAccessTokenId?: string | undefined;
  UserId?: string | undefined;
  Name?: string | undefined;
  DateCreated?: Date | undefined;
  DateLastUsed?: Date | undefined;
  ExpiresTime?: Date | undefined;
  Scopes?: string[] | undefined;
}
export interface ListPersonalAccessTokensResponse {
  NextToken?: string | undefined;
  PersonalAccessTokenSummaries?: PersonalAccessTokenSummary[] | undefined;
}
export interface ListResourceDelegatesRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListResourceDelegatesResponse {
  Delegates?: Delegate[] | undefined;
  NextToken?: string | undefined;
}
export interface ListResourcesFilters {
  NamePrefix?: string | undefined;
  PrimaryEmailPrefix?: string | undefined;
  State?: EntityState | undefined;
}
export interface ListResourcesRequest {
  OrganizationId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  Filters?: ListResourcesFilters | undefined;
}
export interface Resource {
  Id?: string | undefined;
  Email?: string | undefined;
  Name?: string | undefined;
  Type?: ResourceType | undefined;
  State?: EntityState | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
  Description?: string | undefined;
}
export interface ListResourcesResponse {
  Resources?: Resource[] | undefined;
  NextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  ResourceARN: string | undefined;
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Tag[] | undefined;
}
export interface ListUsersFilters {
  UsernamePrefix?: string | undefined;
  DisplayNamePrefix?: string | undefined;
  PrimaryEmailPrefix?: string | undefined;
  State?: EntityState | undefined;
  IdentityProviderUserIdPrefix?: string | undefined;
}
export interface ListUsersRequest {
  OrganizationId: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  Filters?: ListUsersFilters | undefined;
}
export interface User {
  Id?: string | undefined;
  Email?: string | undefined;
  Name?: string | undefined;
  DisplayName?: string | undefined;
  State?: EntityState | undefined;
  UserRole?: UserRole | undefined;
  EnabledDate?: Date | undefined;
  DisabledDate?: Date | undefined;
  IdentityProviderUserId?: string | undefined;
  IdentityProviderIdentityStoreId?: string | undefined;
}
export interface ListUsersResponse {
  Users?: User[] | undefined;
  NextToken?: string | undefined;
}
export interface PutAccessControlRuleRequest {
  Name: string | undefined;
  Effect: AccessControlRuleEffect | undefined;
  Description: string | undefined;
  IpRanges?: string[] | undefined;
  NotIpRanges?: string[] | undefined;
  Actions?: string[] | undefined;
  NotActions?: string[] | undefined;
  UserIds?: string[] | undefined;
  NotUserIds?: string[] | undefined;
  OrganizationId: string | undefined;
  ImpersonationRoleIds?: string[] | undefined;
  NotImpersonationRoleIds?: string[] | undefined;
}
export interface PutAccessControlRuleResponse {}
export interface PutEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
  RoleArn: string | undefined;
  LogGroupArn: string | undefined;
}
export interface PutEmailMonitoringConfigurationResponse {}
export interface PutIdentityProviderConfigurationRequest {
  OrganizationId: string | undefined;
  AuthenticationMode: IdentityProviderAuthenticationMode | undefined;
  IdentityCenterConfiguration: IdentityCenterConfiguration | undefined;
  PersonalAccessTokenConfiguration:
    | PersonalAccessTokenConfiguration
    | undefined;
}
export interface PutIdentityProviderConfigurationResponse {}
export interface PutInboundDmarcSettingsRequest {
  OrganizationId: string | undefined;
  Enforced: boolean | undefined;
}
export interface PutInboundDmarcSettingsResponse {}
export interface PutMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  GranteeId: string | undefined;
  PermissionValues: PermissionType[] | undefined;
}
export interface PutMailboxPermissionsResponse {}
export interface PutMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  Description?: string | undefined;
}
export interface PutMobileDeviceAccessOverrideResponse {}
export interface PutRetentionPolicyRequest {
  OrganizationId: string | undefined;
  Id?: string | undefined;
  Name: string | undefined;
  Description?: string | undefined;
  FolderConfigurations: FolderConfiguration[] | undefined;
}
export interface PutRetentionPolicyResponse {}
export interface RegisterMailDomainRequest {
  ClientToken?: string | undefined;
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface RegisterMailDomainResponse {}
export interface RegisterToWorkMailRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Email: string | undefined;
}
export interface RegisterToWorkMailResponse {}
export interface ResetPasswordRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  Password: string | undefined;
}
export interface ResetPasswordResponse {}
export interface StartMailboxExportJobRequest {
  ClientToken?: string | undefined;
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Description?: string | undefined;
  RoleArn: string | undefined;
  KmsKeyArn: string | undefined;
  S3BucketName: string | undefined;
  S3Prefix: string | undefined;
}
export interface StartMailboxExportJobResponse {
  JobId?: string | undefined;
}
export interface TagResourceRequest {
  ResourceARN: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagResourceResponse {}
export declare class TooManyTagsException extends __BaseException {
  readonly name: "TooManyTagsException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyTagsException, __BaseException>
  );
}
export interface TestAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName?: string | undefined;
  EwsProvider?: EwsAvailabilityProvider | undefined;
  LambdaProvider?: LambdaAvailabilityProvider | undefined;
}
export interface TestAvailabilityConfigurationResponse {
  TestPassed?: boolean | undefined;
  FailureReason?: string | undefined;
}
export interface UntagResourceRequest {
  ResourceARN: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
  EwsProvider?: EwsAvailabilityProvider | undefined;
  LambdaProvider?: LambdaAvailabilityProvider | undefined;
}
export interface UpdateAvailabilityConfigurationResponse {}
export interface UpdateDefaultMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface UpdateDefaultMailDomainResponse {}
export interface UpdateGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface UpdateGroupResponse {}
export interface UpdateImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
  Name: string | undefined;
  Type: ImpersonationRoleType | undefined;
  Description?: string | undefined;
  Rules: ImpersonationRule[] | undefined;
}
export interface UpdateImpersonationRoleResponse {}
export interface UpdateMailboxQuotaRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  MailboxQuota: number | undefined;
}
export interface UpdateMailboxQuotaResponse {}
export interface UpdateMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  MobileDeviceAccessRuleId: string | undefined;
  Name: string | undefined;
  Description?: string | undefined;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  DeviceTypes?: string[] | undefined;
  NotDeviceTypes?: string[] | undefined;
  DeviceModels?: string[] | undefined;
  NotDeviceModels?: string[] | undefined;
  DeviceOperatingSystems?: string[] | undefined;
  NotDeviceOperatingSystems?: string[] | undefined;
  DeviceUserAgents?: string[] | undefined;
  NotDeviceUserAgents?: string[] | undefined;
}
export interface UpdateMobileDeviceAccessRuleResponse {}
export interface UpdatePrimaryEmailAddressRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Email: string | undefined;
}
export interface UpdatePrimaryEmailAddressResponse {}
export interface UpdateResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  Name?: string | undefined;
  BookingOptions?: BookingOptions | undefined;
  Description?: string | undefined;
  Type?: ResourceType | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
}
export interface UpdateResourceResponse {}
export interface UpdateUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  Role?: UserRole | undefined;
  DisplayName?: string | undefined;
  FirstName?: string | undefined;
  LastName?: string | undefined;
  HiddenFromGlobalAddressList?: boolean | undefined;
  Initials?: string | undefined;
  Telephone?: string | undefined;
  Street?: string | undefined;
  JobTitle?: string | undefined;
  City?: string | undefined;
  Company?: string | undefined;
  ZipCode?: string | undefined;
  Department?: string | undefined;
  Country?: string | undefined;
  Office?: string | undefined;
  IdentityProviderUserId?: string | undefined;
}
export interface UpdateUserResponse {}
export declare const EwsAvailabilityProviderFilterSensitiveLog: (
  obj: EwsAvailabilityProvider
) => any;
export declare const CreateAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: CreateAvailabilityConfigurationRequest
) => any;
export declare const CreateResourceRequestFilterSensitiveLog: (
  obj: CreateResourceRequest
) => any;
export declare const CreateUserRequestFilterSensitiveLog: (
  obj: CreateUserRequest
) => any;
export declare const DescribeResourceResponseFilterSensitiveLog: (
  obj: DescribeResourceResponse
) => any;
export declare const DescribeUserResponseFilterSensitiveLog: (
  obj: DescribeUserResponse
) => any;
export declare const ResourceFilterSensitiveLog: (obj: Resource) => any;
export declare const ListResourcesResponseFilterSensitiveLog: (
  obj: ListResourcesResponse
) => any;
export declare const ListUsersFiltersFilterSensitiveLog: (
  obj: ListUsersFilters
) => any;
export declare const ListUsersRequestFilterSensitiveLog: (
  obj: ListUsersRequest
) => any;
export declare const PutRetentionPolicyRequestFilterSensitiveLog: (
  obj: PutRetentionPolicyRequest
) => any;
export declare const ResetPasswordRequestFilterSensitiveLog: (
  obj: ResetPasswordRequest
) => any;
export declare const TestAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: TestAvailabilityConfigurationRequest
) => any;
export declare const UpdateAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: UpdateAvailabilityConfigurationRequest
) => any;
export declare const UpdateResourceRequestFilterSensitiveLog: (
  obj: UpdateResourceRequest
) => any;
export declare const UpdateUserRequestFilterSensitiveLog: (
  obj: UpdateUserRequest
) => any;
